Index: content/browser/renderer_host/render_process_host.h |
diff --git a/content/browser/renderer_host/render_process_host.h b/content/browser/renderer_host/render_process_host.h |
index b38402658e297a0061e09cfe23dec2f20da1c73a..3c3f7a0a301996bf29b838d2fa23fa0b1a159a85 100644 |
--- a/content/browser/renderer_host/render_process_host.h |
+++ b/content/browser/renderer_host/render_process_host.h |
@@ -17,7 +17,7 @@ |
#include "ui/gfx/surface/transport_dib.h" |
class Profile; |
-struct ViewMsg_ClosePage_Params; |
+struct ViewMsg_SwapOut_Params; |
namespace base { |
class SharedMemory; |
@@ -167,12 +167,12 @@ class RenderProcessHost : public IPC::Channel::Sender, |
// the specified render widget. |
virtual void CancelResourceRequests(int render_widget_id) = 0; |
// Called on the UI thread to simulate a ClosePage_ACK message to the |
// ResourceDispatcherHost. Necessary for a cross-site request, in the case |
// that the original RenderViewHost is not live and thus cannot run an |
- // onunload handler. |
- virtual void CrossSiteClosePageACK( |
- const ViewMsg_ClosePage_Params& params) = 0; |
+ // unload handler. |
+ virtual void CrossSiteSwapOutACK( |
+ const ViewMsg_SwapOut_Params& params) = 0; |
// Called on the UI thread to wait for the next UpdateRect message for the |
// specified render widget. Returns true if successful, and the msg out- |
@@ -190,6 +190,13 @@ class RenderProcessHost : public IPC::Channel::Sender, |
virtual void WidgetHidden() = 0; |
virtual int VisibleWidgetCount() const = 0; |
+ // Track the count of pending views that are being swapped back in. Called |
+ // by listeners to register and unregister pending views to prevent the |
+ // process from exiting. |
+ virtual void AddPendingView() = 0; |
+ virtual void RemovePendingView() = 0; |
+ virtual int PendingViewCount() const = 0; |
+ |
// Try to shutdown the associated renderer process as fast as possible. |
// If this renderer has any RenderViews with unload handlers, then this |
// function does nothing. The current implementation uses TerminateProcess. |
@@ -167,12 +167,12 @@ class RenderProcessHost : public IPC::Channel::Sender, |
// the specified render widget. |
virtual void CancelResourceRequests(int render_widget_id) = 0; |
- // Called on the UI thread to simulate a ClosePage_ACK message to the |
+ // Called on the UI thread to simulate a SwapOut_ACK message to the |
// ResourceDispatcherHost. Necessary for a cross-site request, in the case |
// that the original RenderViewHost is not live and thus cannot run an |